==> nextcloud-app-bookmarks-1:4.0.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/bookmarks/l10n/lv.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Grāmatzīmes",
    "No file provided for import" : "Nav norādīta importējamā datne",
    "Unsupported file type for import" : "Importam neatbalstīts datnes tips",
    "A Bookmark manager for Nextcloud" : "Nextcloud grāmatzīmju pārvaldnieks",
    "Details" : "Detaļas",
    "Rename" : "Pārsaukt",
    "Move" : "Pārvietot",
    "Delete" : "Dzēst",
    "Search" : "Meklēt",
    "New" : "Jauns",
    "New folder" : "Jauna mape",
    "Grid view" : "Režģa izkārtojums",
    "List view" : "Saraksta izkārtojums",
    "Select all" : "Atzīmēt visu",
    "Submit" : "Iesniegt",
    "Cancel" : "Atcelt",
    "Recent" : "Nesenās",
    "Add a bookmark" : "Pievienot grāmatzīmi",
    "Import" : "Importēt",
    "Export" : "Eksportēt",
    "Recently added" : "Nesen pievienoja",
    "Alphabetically" : "Alfabētiskā secībā",
    "Most visited" : "Visapmeklētākie",
    "Last modified" : "Pēdējoreiz modificēts",
    "Bookmarklet" : "Grāmatzīme",
    "Clear data" : "Notīrīt datus",
    "Delete all bookmarks" : "Dzēst visas grāmatzīmes",
    "Do you really want to delete all your bookmarks?" : "Vai tiešām vēlaties dzēst visas savas grāmatzīmes?",
    "Title" : "Amats",
    "Link" : "Saite",
    "Tags" : "Birkas",
    "Attachments" : "Pielikumi",
    "Notes" : "Piezīmes",
    "Owner" : "Īpašnieks",
    "Sharing" : "Koplietošana",
    "Share link" : "Koplietot saiti",
    "Copy link" : "Kopēt saiti",
    "Allow editing" : "Atļaut rediģēšanu",
    "Link copied" : "Saite nokopēta",
    "Select" : "Atzīmēt",
    "Previews" : "Priekšskatījumi",
    "Screeenly API URL" : "Screeenly API saite",
    "Screeenly API key" : "Screeenly API atslēga",
    "Privacy" : "Privātums",
    "This URL is already bookmarked! Overwrite?" : "Šī saite jau ir grāmatzīmēs! Vai pārrakstīt?",
    "Folder" : "Mape",
    "Save" : "Saglabāt",
    "Bookmarks feed" : "Grāmatzīmju plūsma"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");

==> nextcloud-app-bookmarks-1:15.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/bookmarks/l10n/lv.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Grāmatzīmes",
    "No file provided for import" : "Nav norādīta importējamā datne",
    "Bookmark" : "Grāmatzīme",
    "Details" : "Detaļas",
    "Rename" : "Pārsaukt",
    "Copy link" : "Kopēt saiti",
    "Move" : "Pārvietot",
    "Select all" : "Atzīmēt visu",
    "Go back" : "Atpakaļ",
    "New" : "Jauns",
    "New folder" : "Jauna mape",
    "Search" : "Meklēt",
    "Empty trash bin" : "Izdzēst miskastes saturu",
    "Add a bookmark" : "Pievienot grāmatzīmi",
    "Rename folder" : "Pārsaukt mapi",
    "Choose folder" : "Izvēlies mapi",
    "Submit" : "Iesniegt",
    "Cancel" : "Atcelt",
    "Recent" : "Nesenās",
    "Shared with you" : "Koplietots ar jums",
    "Files" : "Datnes",
    "Delete" : "Dzēst",
    "Bookmarklet" : "Grāmatzīme",
    "Need help?" : "Vajadzīga palīdzība?",
    "Title" : "Amats",
    "Link" : "Saite",
    "Tags" : "Birkas",
    "Notes" : "Piezīmes",
    "Notes for this bookmark …" : "Šīs grāmatzīmes piezīmes …",
    "Download file" : "Lejupielādēt datni",
    "Owner" : "Īpašnieks",
    "Sharing" : "Koplietošana",
    "Share link" : "Koplietot saiti",
    "Allow editing" : "Atļaut labošanu",
    "Allow resharing" : "Atļaut atkārtotu koplietošanu",
    "Link copied" : "Saite nokopēta",
    "Privacy" : "Privātums",
    "Previews" : "Priekšskatījumi",
    "Screeenly API URL" : "Screeenly API saite",
    "Screeenly API key" : "Screeenly API atslēga",
    "Failed to save settings" : "Neizdevās saglabāt iestatījumus",
    "This URL is already bookmarked! Overwrite?" : "Šī saite jau ir grāmatzīmēs! Vai pārrakstīt?",
    "Folder" : "Mape",
    "Save" : "Saglabāt",
    "Bookmarks feed" : "Grāmatzīmju plūsma"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
